@@ -40,6 +40,6 @@ def url_qualifier(request):
     try:
         match = resolve(request.path_info)
         return {'url_qualifier': '%s:%s' % (
-            match.url_namespace, match.url_name)}
+            match.namespace, match.url_name)}
     except Http404:
         return {'url_qualifier': None}
